# MCModUpdater

A utility to update and install Minecraft mods for java edition.

## FAQ

### Why did you build this?

I built this because I wanted to use Minecrafts default launcher but still be able to easily install and update mods like in Modrinths launcher.
